pub struct RequestInfo {
pub version: String,
pub block_version: u64,
pub p2p_version: u64,
pub abci_version: String,
}Expand description
Return information about the application state.
Used to sync Tenderdash with the application during a handshake that happens on startup. The returned app_version will be included in the Header of every block. Tenderdash expects last_block_app_hash and last_block_height to be updated during Commit, ensuring that Commit is never called twice for the same block height.
Fields
version: StringThe Tenderdash software semantic version.
block_version: u64The Tenderdash Block Protocol version.
p2p_version: u64The Tenderdash P2P Protocol version.
abci_version: StringThe Tenderdash ABCI semantic version.