pub struct RequestInitChain {
pub time: Option<Timestamp>,
pub chain_id: String,
pub consensus_params: Option<ConsensusParams>,
pub validator_set: Option<ValidatorSetUpdate>,
pub app_state_bytes: Vec<u8>,
pub initial_height: i64,
pub initial_core_height: u32,
}Expand description
Called once upon genesis.
- If ResponseInitChain.Validators is empty, the initial validator set will be the RequestInitChain.Validators
- If ResponseInitChain.Validators is not empty, it will be the initial validator set (regardless of what is in RequestInitChain.Validators).
- This allows the app to decide if it wants to accept the initial validator set proposed by Tenderdash (ie. in the genesis file), or if it wants to use a different one (perhaps computed based on some application specific information in the genesis file).
Fields
time: Option<Timestamp>Genesis time
chain_id: StringID of the blockchain.
consensus_params: Option<ConsensusParams>Initial consensus-critical parameters.
validator_set: Option<ValidatorSetUpdate>Initial genesis validators, sorted by voting power.
app_state_bytes: Vec<u8>Serialized initial application state. JSON bytes.
initial_height: i64Height of the initial block (typically 1).
initial_core_height: u32Initial core chain lock height.