pub struct RequestLoadSnapshotChunk {
pub height: u64,
pub version: u32,
pub chunk_id: Vec<u8>,
}Expand description
Used during state sync to retrieve snapshot chunks from peers.
Fields
height: u64The height of the snapshot the chunks belongs to.
version: u32The application-specific format of the snapshot the chunk belongs to.
chunk_id: Vec<u8>The chunk id is a hash of the node of subtree of the snapshot.