pub struct RequestOfferSnapshot {
pub snapshot: Option<Snapshot>,
pub app_hash: Vec<u8>,
}Expand description
Offers a snapshot to the application.
- OfferSnapshot is called when bootstrapping a node using state sync. The application may accept or reject snapshots as appropriate. Upon accepting, Tenderdash will retrieve and apply snapshot chunks via ApplySnapshotChunk. The application may also choose to reject a snapshot in the chunk response, in which case it should be prepared to accept further OfferSnapshot calls.
- Only AppHash can be trusted, as it has been verified by the light client. Any other data can be spoofed by adversaries, so applications should employ additional verification schemes to avoid denial-of-service attacks. The verified AppHash is automatically checked against the restored application at the end of snapshot restoration.
- For more information, see the Snapshot data type or the state sync section.
Fields
snapshot: Option<Snapshot>The snapshot offered for restoration.
app_hash: Vec<u8>The light client-verified app hash for this height, from the blockchain. 32 bytes.