RequestVerifyVoteExtension

Struct RequestVerifyVoteExtension 

pub struct RequestVerifyVoteExtension {
    pub hash: Vec<u8>,
    pub validator_pro_tx_hash: Vec<u8>,
    pub height: i64,
    pub round: i32,
    pub vote_extensions: Vec<ExtendVoteExtension>,
}
Verify the vote extension

Usage
  • RequestVerifyVoteExtension.vote_extension can be an empty byte array. The Application’s interpretation of it should be that the Application running at the process that sent the vote chose not to extend it. Tenderdash will always call RequestVerifyVoteExtension, even for 0 length vote extensions.
  • If ResponseVerifyVoteExtension.status is REJECT, Tenderdash will reject the whole received vote. See the Requirements section to understand the potential liveness implications of this.
  • The implementation of VerifyVoteExtension MUST be deterministic. Moreover, the value of ResponseVerifyVoteExtension.status MUST exclusively depend on the parameters passed in the call to RequestVerifyVoteExtension, and the last committed Application state (see Requirements section).
  • Moreover, application implementers SHOULD always set ResponseVerifyVoteExtension.status to ACCEPT, unless they really know what the potential liveness implications of returning REJECT are.
When does Tenderdash call it?

When a validator p is in Tenderdash consensus round r, height h, state prevote (TODO discuss: I think I must remove the state from this condition, but not sure), and p receives a Precommit message for round r, height h from q:

  1. If the Precommit message does not contain a vote extensions with a valid signature, Tenderdash discards the message as invalid.
  • a 0-length vote extensions is valid as long as its accompanying signature is also valid.
  1. Else, p’s Tenderdash calls RequestVerifyVoteExtension.
  2. The Application returns accept or reject via ResponseVerifyVoteExtension.status.
  3. If the Application returns
  • accept, p’s Tenderdash will keep the received vote, together with its corresponding vote extension in its internal data structures. It will be used to populate the ExtendedCommitInfo structure in calls to RequestPrepareProposal, in rounds of height h + 1 where p is the proposer.
  • reject, p’s Tenderdash will deem the Precommit message invalid and discard it.

Fields

hash: Vec<u8>

The header hash of the propsed block that the vote extensions refers to.

validator_pro_tx_hash: Vec<u8>

ProTxHash of the validator that signed the extensions.

height: i64

Height of the block (for sanity check).

round: i32

// Round number for the block.

vote_extensions: Vec<ExtendVoteExtension>

Application-specific information signed by Tenderdash. Can have 0 length.