pub struct ResponseQuery {
pub code: u32,
pub log: String,
pub info: String,
pub index: i64,
pub key: Vec<u8>,
pub value: Vec<u8>,
pub proof_ops: Option<ProofOps>,
pub height: i64,
pub codespace: String,
}Fields
code: u32Response code.
log: StringThe output of the application’s logger. May be non-deterministic.
info: StringAdditional information. May be non-deterministic.
index: i64The index of the key in the tree.
key: Vec<u8>The key of the matching data.
value: Vec<u8>The value of the matching data.
proof_ops: Option<ProofOps>Serialized proof for the value data, if requested, to be verified against the app_hash for the given Height.
height: i64The block height from which data was derived. Note that this is the height of the block containing the application’s Merkle root hash, which represents the state as it was after committing the block at Height-1.
codespace: StringNamespace for the code.