pub struct ResponseVerifyVoteExtension {
pub status: i32,
}Fields
status: i32enum signaling if the application accepts the vote extension
Implementations
Sourceimpl ResponseVerifyVoteExtension
impl ResponseVerifyVoteExtension
Sourcepub fn status(&self) -> VerifyStatus
pub fn status(&self) -> VerifyStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: VerifyStatus)
pub fn set_status(&mut self, value: VerifyStatus)
Sets status to the provided enum value.