pub struct RequestQuery {
pub data: Vec<u8>,
pub path: String,
pub height: i64,
pub prove: bool,
}Expand description
Query for data from the application at current or past height.
- Optionally return Merkle proof.
- Merkle proof includes self-describing type field to support many types of Merkle trees and encoding formats.
Fields
data: Vec<u8>Raw query bytes. Can be used with or in lieu of Path.
path: StringPath field of the request URI. Can be used with or in lieu of data. Apps MUST interpret /store as a query by key on the underlying store. The key SHOULD be specified in the data field. Apps SHOULD allow queries over specific types like /accounts/… or /votes/…
height: i64The block height for which you want the query (default=0 returns data for the latest committed block). Note that this is the height of the block containing the application’s Merkle root hash, which represents the state as it was after committing the block at Height-1.
prove: boolReturn Merkle proof with response if possible.